Please see [https://docs.mlcommons.org/cm4mlops/scripts/Cloud-automation/install-aws-cli](https://docs.mlcommons.org/cm4mlops/scripts/Cloud-automation/install-aws-cli) for the documentation of this CM script.
